# Open-Imx:Icons

![imxInsights logo](https://raw.githubusercontent.com/open-imx/imxIcons/main/docs/assets/logo.svg#only-dark#gh-dark-mode-only)
![imxInsights logo](https://raw.githubusercontent.com/open-imx/imxIcons/main/docs/assets/logo-light.svg#only-light#gh-light-mode-only)


**Documentation**: <a href="https://open-imx.github.io/imxIcons/" target="_blank">https://open-imx.github.io/imxIcons/</a>

**Source Code**: <a href="https://github.com/open-imx/ImxIcons" target="_blank">https://github.com/open-imx/imxIcons</a>

**PyPi**: <a href="https://pypi.org/project/imxIcons/" target="_blank">https://pypi.org/project/imxIcons/</a>

**imxIcons** is a Python library that provides an intuitive and unified set of standardized icons representing IMX objects based on their properties. 
By transforming complex IMX data into clear visual representations, **imxIcons** enhances user experiences across applications in the railway sector. 
These icons help streamline the visualization of railway data across various tools and applications, improving the accessibility and user-friendliness of IMX data. 

*This is a personal project and therefore no responsibility for the functionality, accuracy, or usage of this library.*

## Features
- [X] Get IMX icons by giving a object path and a set of properties.
- [X] Return SVG icon by name or url
- [X] SVG QGIS support


### Backlog and Roadmap
<a href="https://github.com/orgs/open-imx/projects/4/" target="_blank">https://github.com/orgs/open-imx/projects/4/</a>

## Supported Python Versions

!!! warning  
    ***Python Typehints are awesome therefor 3.9 and below will NOT be supported***.

## Distribution and installation
Just install the library

```pip install imxIcons```

for a demo see: https://imx-icons-api.azurewebsites.net/

## Contributing
Contributions welcome! [Join our Discord Community](https://discord.gg/wBses7bPFg) 
